<div align="center">

<img src="https://github.com/joeyagreco/sleeper/raw/main/img/sleeper_logo_alt.png" alt="sleeper logo" width="250"/>

A Python wrapper for the Sleeper API.

[Sleeper Website](https://sleeper.com/)\
[Sleeper API Documentation](https://docs.sleeper.app/)

<a target="_blank" href="https://www.python.org/downloads/" title="Python version"><img src="https://img.shields.io/badge/python-%3E=_3.10-teal.svg"></a>
![Main Build](https://github.com/joeyagreco/sleeper/actions/workflows/main-build.yml/badge.svg)
![Last Commit](https://img.shields.io/github/last-commit/joeyagreco/sleeper)
</div>

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install.

```bash
pip install sleeper
```

## Usage

For examples on how to utilize the different features of this library, see
the [`example`](https://github.com/joeyagreco/sleeper/tree/main/example) folder.

## Running Tests

To run tests, run the following command:

```bash
  pytest
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)